<?xml version="1.0" ?><!DOCTYPE TS><TS language="sl" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>Pregledovalnik fotografij Deepin</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Različica:</translation>
    </message>
    <message>
        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
        <translation>Pregledovalnik fotografij Deepin je gladek in moden upravitelj fotografij.</translation>
    </message>
    <message>
        <source>It is featured with image management, image viewing and basic image editing.</source>
        <translation>Z njim je možno upravljati, pregledovati in osnovno urejati fotografije.</translation>
    </message>
</context>
<context>
    <name>AlbumBTContent</name>
    <message>
        <source>image</source>
        <translation>slika</translation>
    </message>
    <message>
        <source>images</source>
        <translation>slike</translation>
    </message>
    <message>
        <source>album</source>
        <translation>album</translation>
    </message>
    <message>
        <source>albums</source>
        <translation>albumi</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>Upravljaj sinhronizacijo</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>Sinhroniziram:</translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>V redu</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nov album</translation>
    </message>
    <message>
        <source>Unnamed</source>
        <translation>Neimenovano</translation>
    </message>
</context>
<context>
    <name>AlbumDelegate</name>
    <message>
        <source>Recent imported</source>
        <translation>Pred kratkim uvoženo</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Priljubljene</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Are your sure to delete this album?</source>
        <translation>Res hočete izbrisati ta album?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
</context>
<context>
    <name>AlbumPanel</name>
    <message>
        <source>Back</source>
        <translation>Nazaj</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Priljubljene</translation>
    </message>
    <message>
        <source>Timeline</source>
        <translation>Časovnica</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Lahko dodate sinhroniziran direktorij ali povlecite in spustite fotografije v časovnico</translation>
    </message>
</context>
<context>
    <name>AlbumsView</name>
    <message>
        <source>Unnamed</source>
        <translation>Neimenovano</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Pogled</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diaprojekcija</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Preimenuj</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiraj</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>Pregledovalnik fotografij Deepin</translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>Slike</translation>
    </message>
</context>
<context>
    <name>DirImportDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>V redu</translation>
    </message>
    <message>
        <source>Are you sure to add the pictures to the album?</source>
        <translation>Res hočete dodati fotografijo v album?</translation>
    </message>
    <message>
        <source>Sync and Create</source>
        <translation>Sinhroniziraj in ustvari</translation>
    </message>
    <message>
        <source>Sync</source>
        <translation>Sinhroniziraj</translation>
    </message>
    <message>
        <source>Are you sure to add to the sync list and create the album named after this folder?</source>
        <translation>Res hočete dodati na seznam sinhroniziranja in ustvariti album, imenovan po tej mapi?</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</source>
        <translation>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</translation>
    </message>
    <message>
        <source>Exported successfully</source>
        <translation>Uspešno izvoženo</translation>
    </message>
    <message>
        <source>Failed to export</source>
        <translation>Izvoz ni uspel</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Shrani</translation>
    </message>
</context>
<context>
    <name>FileDeleteDialog</name>
    <message>
        <source>Are you sure to throw pictures to TRASH?</source>
        <translation>Res hočete vreči slike v KOŠ?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Image info</source>
        <translation>Informacije o sliki</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation>Ta datoteka vsebuje več strani, za ogled vseh strani uporabite Evince.</translation>
    </message>
</context>
<context>
    <name>ImagesView</name>
    <message>
        <source>View</source>
        <translation>Pogled</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Čez cel zaslon</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diaprojekcija</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Natisni</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiraj</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Kopiraj v odložišče</translation>
    </message>
    <message>
        <source>Throw to trash</source>
        <translation>Vrzi v smeti</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Odstrani iz albuma</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Dodaj med priljubljene</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Odstrani iz priljubljenih</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Zasukaj v desno</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Zasukaj v levo</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Nastavi za ozadje</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Prikaži v upravitelju datotek</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informacije o sliki</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Lahko dodate sinhroniziran direktorij ali povlecite in spustite fotografije v časovnico</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Dodaj v album</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Dodaj v nov album</translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation>Odpri direktorij</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Nimate dovoljenja za ogled slike</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Ime</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Vrsta</translation>
    </message>
    <message>
        <source>Date photoed</source>
        <translation>Datum nastanka</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Datum spremembe</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Ločljivost</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Velikost datoteke</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Barvni model</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Način osvetlitve</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Program osvetlitve</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Čas osvetlitve</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Flash</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Zaslonka</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Goriščna razdalja</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Največja zaslonka</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Način Metering</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Uravnavanje beline</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Kompenzacija flasha</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Model kamere</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Model leč</translation>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation>Brez spreminjanja velikosti</translation>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation>Prilagodi stran na sliko</translation>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation>Prilagodi sliko na stran</translation>
    </message>
    <message>
        <source>Scale to:</source>
        <translation>Povečaj/pomanjšaj na:</translation>
    </message>
    <message>
        <source>Millimeters</source>
        <translation>milimetrov</translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation>centimetrov</translation>
    </message>
    <message>
        <source>Inches</source>
        <translation>palcev</translation>
    </message>
    <message>
        <source>Image Position</source>
        <translation>Položaj slike</translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation>Sprememba velikosti</translation>
    </message>
    <message>
        <source>Image Settings</source>
        <translation>Nastavitve slike</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation>Senčila</translation>
    </message>
    <message>
        <source>Switcher</source>
        <translation>Menjalnik</translation>
    </message>
    <message>
        <source>Sliding</source>
        <translation>Drsenje</translation>
    </message>
    <message>
        <source>Ring</source>
        <translation>Prstan</translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>Izberi direktorij</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation>Temu direktoriju je onemogočena sinhronizacija</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>Dodaj mapo</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation>Upravljanje sinhroniziranja direktorijev</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation>Seznam direktorijev je prazen</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>Prekliči sinhronizacijo</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Fotografije</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>Naprava je bila odstranjena</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>Direktorij ne obstaja več</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>Preračunavam...</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>Pregledovanje fotografij</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavitve</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Pogled</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Čez cel zaslon</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diaprojekcija</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Končaj diaprojekcijo</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiraj</translation>
    </message>
    <message>
        <source>Throw to trash</source>
        <translation>Vrzi v smeti</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Odstrani iz albuma</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Dodaj med priljubljene</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Odstrani iz priljubljenih</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Zasukaj v desno</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Zasukaj v levo</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Nastavi za ozadje</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Prikaži v upravitelju datotek</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informacije o sliki</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Predhodna</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Naslednja</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>Predhodni zaslon</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>Naslednji zaslon</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nov album</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Preimenuj</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Pomoč</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Izhod</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Prikaži bližnjice</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation>Prosim, vnesite novo bližnjico</translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation>Bližnjice</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation>Prikaži sliko</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>Ponastavi na privzeto</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation>Pogled</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Čez cel zaslon</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diaprojekcija</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Končaj diaprojekcijo</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Natisni</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiraj</translation>
    </message>
    <message>
        <source>Throw to trash</source>
        <translation>Vrzi v smeti</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Odstrani iz albuma</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Dodaj med priljubljene</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Odstrani iz priljubljenih</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Zasukaj v desno</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Zasukaj v levo</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Nastavi za ozadje</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Prikaži v upravitelju datotek</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informacije o sliki</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nov album</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Preimenuj</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
</context>
<context>
    <name>SlideShowPanel</name>
    <message>
        <source>End show</source>
        <translation>Končaj diaprojekcijo</translation>
    </message>
    <message>
        <source>Pause/Play</source>
        <translation>Premor/Predvajaj</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Nastavitve prosojnice</translation>
    </message>
    <message>
        <source>Switch effect</source>
        <translation>Učinek menjavanja</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Čas trajanja</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation>Čas menjavanja</translation>
    </message>
    <message>
        <source>second</source>
        <translation>sekunda</translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation>Nazaj</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation>Upravljanje fotografije</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Priljubljene</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1 Velikost</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Na velikost okna</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Zasukaj v levo</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Zasukaj v desno</translation>
    </message>
    <message>
        <source>Throw to Trash</source>
        <translation>Vrzi v smeti</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Odstrani iz priljubljenih</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Dodaj med priljubljene</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Ne najdem fotografij</translation>
    </message>
</context>
<context>
    <name>TimelineBTContent</name>
    <message>
        <source>%1 image</source>
        <translation>%1 fotografija</translation>
    </message>
    <message>
        <source>%1 images</source>
        <translation>%1 fotografij</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>Upravljaj sinhroniziranje</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>Sinhroniziram:</translation>
    </message>
</context>
<context>
    <name>TimelinePanel</name>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Lahko dodate sinhroniziran direktorij ali povlecite in spustite fotografije v časovnico</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Dodaj v album</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Dodaj v nov album</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Pogled</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Čez cel zaslon</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diaprojekcija</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Natisni</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiraj</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Kopiraj v odložišče</translation>
    </message>
    <message>
        <source>Throw to trash</source>
        <translation>Vrzi v smeti</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Dodaj med priljubljene</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Odstrani iz priljubljenih</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Zasukaj v desno</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Zasukaj v levo</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Nastavi za ozadje</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Prikaži v upravitelju datotek</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informacije o sliki</translation>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Nastavitve prosojnice</translation>
    </message>
    <message>
        <source>Effect</source>
        <translation>Učinek</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Čas trajanja</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Bližnjice</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Pogled</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
</context>
<context>
    <name>TopAlbumTips</name>
    <message>
        <source>dd MMMM yyyy</source>
        <translation>dd MMMM llll</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Priljubljene</translation>
    </message>
    <message>
        <source>Recent imported</source>
        <translation>Pred kratkim uvoženo</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation>Nov album</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavitve</translation>
    </message>
    <message>
        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
        <translation>Pregledovalnik fotografij Deepin je gladek in moden upravitelj fotografij.</translation>
    </message>
    <message>
        <source>It is featured with image management, image viewing and basic image editing.</source>
        <translation>Z njim je možno upravljati, pregledovati in osnovno urejati fotografije.</translation>
    </message>
    <message>
        <source>Dark theme</source>
        <translation>Temna tema</translation>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation>Časovnica</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Dodaj v album</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Dodaj v nov album</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Izhod iz celega zaslona</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Čez cel zaslon</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diaprojekcija</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Natisni</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiraj</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Kopiraj v odložišče</translation>
    </message>
    <message>
        <source>Throw to trash</source>
        <translation>Vrzi v smeti</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Odstrani iz albuma</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Dodaj med priljubljene</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Odstrani iz priljubljenih</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Pokaži navigacijsko okno</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Skrij navigacijsko okno</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Zasukaj v desno</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Zasukaj v levo</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Nastavi za ozadje</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Prikaži v upravitelju datotek</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informacije o sliki</translation>
    </message>
</context>
</TS>